# Gzip


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cache_condition** | **str, none_type** | Name of the cache condition controlling when this configuration applies. | [optional] 
**content_types** | **str, none_type** | Space-separated list of content types to compress. If you omit this field a default list will be used. | [optional] 
**extensions** | **str, none_type** | Space-separated list of file extensions to compress. If you omit this field a default list will be used. | [optional] 
**name** | **str** | Name of the gzip configuration. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


